##############################################################
# Sascha Wolfer
# IDS, Abt. Lexik
#
# - Auswertung Schreibumgebungsannotationen
# - Grundlage: Long-format Ergebnisdatei mit angereicherten
#              Informationen aus Unipark-Datei
# Juni 2015
##############################################################
# Einlesescript: 'SU_annot_einlesen.R'

library(sciplot)
library(lme4)
library(RColorBrewer)
library(effects)

rm(list=ls())

verzeichnis.win <- "<path>"
verzeichnis.mac <- "<path>"
if (Sys.info()["sysname"] == "Darwin") setwd(verzeichnis.mac) else setwd(verzeichnis.win)
rm(list=c("verzeichnis.mac", "verzeichnis.win"))

# Ergebnisdatei einlesen
results <- readRDS("SU_results.Rds")

# kleinere Kodierungen ----------------------------------------------------
results$Bedingung <- factor(results$Bedingung, levels = c("nur Text", "Markierung", "Hilfsmittel"))
results$Ueberarb.typ <- ifelse(results$Ueberarb.typ == "a ", "a",
                               ifelse(results$Ueberarb.typ == "ae ", "ae",
                                      ifelse(results$Ueberarb.typ == "r ", "r",
                                             ifelse(results$Ueberarb.typ == "ref ", "ref",
                                                    results$Ueberarb.typ))))
results$Typ.a <- grepl("a", results$Ueberarb.typ, fixed = T)
results$Typ.k <- grepl("k", results$Ueberarb.typ, fixed = T)
results$Typ.v <- grepl("v", results$Ueberarb.typ, fixed = T)
results$Typ.ref <- grepl("ref", results$Ueberarb.typ, fixed = T)
results$Typ.rep <- grepl("rep", results$Ueberarb.typ, fixed = T)
results$Typ.r <- results$Ueberarb.typ %in% c("arv", "er", "r", "rref")
results$Typ.e <- results$Ueberarb.typ %in% c("ae", "e", "er", "eref", "erep")

results$Ueberarb.typ2 <- results$Ueberarb.typ
# Überarbeitungstypen-Ersetzungsliste
typen.labels <- list(c("a", "Austausch"),
                     c("k", "keine Üa."),
                     c("r", "Reduktion"),
                     c("ref", "Reformulierung"),
                     c("rep", "Reparatur"),
                     c("v", "Verschiebung"),
                     c("ae", "A+E"),
                     c("ar", "A+R"),
                     c("e", "Erweiterung"),
                     c("arv", "A+R+V"),
                     c("arep", "A+Rep"),
                     c("erep", "E+Rep"),
                     c("rref", "R+Ref"),
                     c("aref", "A+Ref"),
                     c("er", "E+R"),
                     c("eref", "E+Ref"))
for (label in typen.labels) {
  results$Ueberarb.typ2 <- gsub(paste0("^", label[1], "$"), label[2], results$Ueberarb.typ2)
}
rm(list=c("label", "typen.labels"))

## Ausgabe und Einlesen von Stolperstein-Informationen
results$Stolperstein.ID <- paste(results$Text, results$Stolperstein, sep = ".")
st.inf <- read.table("stolper.infos.txt", sep = "\t", fileEnc = "UTF-8", header = T)
results <- merge(results, st.inf, by = "Stolperstein.ID", all.x = T, all.y = F)
rm(st.inf)

## Korrekturen der Annotationen
# 1) ID: 1a859a5ece115ae66534f07801e0b7b8, Text Jugend, Stolperstein 16: Kategorie „verbessert“: b
# 2) ID: 2b41c9d03ae1929a8361cf72668186f5, Text Jugend, Stolperstein 15:  Kategorie „verbessert“: b
# 3) ID: 63e891981550fad60a0d0c158ad60ed4, Text Jugend, Stolperstein 12: Kategorie „verbessert“: b
# 4) ID: 63e891981550fad60a0d0c158ad60ed4, Text Phraseo, Stolperstein 7: Kategorie „verbessert“: s
# 5) ID: dc961eff94cc9c0bcc349485656dc9c9, Text Jugend, Stolperstein 10: Kategorie „verbessert“: s
# 
# 6) ID: 032a98345a1a78ba7d8048e48dba0147,  Text Jugend, Stolperstein 1: Kategorie „Überarbeitungstyp“: ae
# 7) ID: b352bb0120ec9bb151bc40c789e7b60c, Text Jugend, Stolperstein 2: Kategorie „Überarbeitungstyp“: a
# 8) ID:  54d3bb9002408f6cdef91cc4854ad2f4, Text Phraseo, Stolperstein 7: Kategorie „Überarbeitungstyp“: r
# 9) ID: acd8bb6267730001817a43bf731c6907, Text Jugend, Stolperstein 4: Kategorie „Überarbeitungstyp: ref
# 10) ID: acd8bb6267730001817a43bf731c6907, Text Phraseo, Stolperstein 8: Kategorie „Überarbeitungstyp“: ref
# 11) ID: b352bb0120ec9bb151bc40c789e7b60c, Text Phraseo, Stolperstein 7: Kategorie „Überarbeitungstyp": ref
# 12) ID: 142be3cb830c03ee47b2718e29c9c9c3, Text Jugend, Stolperstein 16: Kategorie „Überarbeitungstyp“: e

results[results$VTn == "1a859a5ece115ae66534f07801e0b7b8" &
          results$Text == "Jugend" &
          results$Stolperstein == 16, "verbessert"] <- "b"
results[results$VTn == "2b41c9d03ae1929a8361cf72668186f5" &
          results$Text == "Jugend" &
          results$Stolperstein == 15, "verbessert"] <- "b"
results[results$VTn == "63e891981550fad60a0d0c158ad60ed4" &
          results$Text == "Jugend" &
          results$Stolperstein == 12, "verbessert"] <- "b"
results[results$VTn == "63e891981550fad60a0d0c158ad60ed4" &
          results$Text == "Phraseo" &
          results$Stolperstein == 7, "verbessert"] <- "s"
results[results$VTn == "dc961eff94cc9c0bcc349485656dc9c9" &
          results$Text == "Jugend" &
          results$Stolperstein == 10, "verbessert"] <- "b"

results[results$VTn == "032a98345a1a78ba7d8048e48dba0147" &
          results$Text == "Jugend" &
          results$Stolperstein == 1, "Ueberarb.typ"] <- "ae"
results[results$VTn == "b352bb0120ec9bb151bc40c789e7b60c" &
          results$Text == "Jugend" &
          results$Stolperstein == 2, "Ueberarb.typ"] <- "a"
results[results$VTn == "54d3bb9002408f6cdef91cc4854ad2f4" &
          results$Text == "Phraseo" &
          results$Stolperstein == 7, "Ueberarb.typ"] <- "r"
results[results$VTn == "acd8bb6267730001817a43bf731c6907" &
          results$Text == "Jugend" &
          results$Stolperstein == 4, "Ueberarb.typ"] <- "ref"
results[results$VTn == "acd8bb6267730001817a43bf731c6907" &
          results$Text == "Phraseo" &
          results$Stolperstein == 8, "Ueberarb.typ"] <- "ref"
results[results$VTn == "b352bb0120ec9bb151bc40c789e7b60c" &
          results$Text == "Phraseo" &
          results$Stolperstein == 7, "Ueberarb.typ"] <- "ref"
results[results$VTn == "142be3cb830c03ee47b2718e29c9c9c3" &
          results$Text == "Jugend" &
          results$Stolperstein == 16, "Ueberarb.typ"] <- "e"
results$Ueberarb.typ2 <- results$Ueberarb.typ

# Überarbeitungstypen-Ersetzungsliste
typen.labels <- list(c("a", "Austausch"),
                     c("k", "keine Üa."),
                     c("r", "Reduktion"),
                     c("ref", "Reformulierung"),
                     c("rep", "Reparatur"),
                     c("v", "Verschiebung"),
                     c("ae", "A+E"),
                     c("ar", "A+R"),
                     c("e", "Erweiterung"),
                     c("arv", "A+R+V"),
                     c("arep", "A+Rep"),
                     c("erep", "E+Rep"),
                     c("rref", "R+Ref"),
                     c("aref", "A+Ref"),
                     c("er", "E+R"),
                     c("eref", "E+Ref"))
for (label in typen.labels) {
  results$Ueberarb.typ2 <- gsub(paste0("^", label[1], "$"), label[2], results$Ueberarb.typ2)
}
rm(list=c("label", "typen.labels"))

# Stolpersteinstatistiken -------------------------------------------------

# „verbessert":
# b (= besser), 
# g (= gleich geblieben)
# s (= schlechter), 
# si (= sinnentstellt; Sinn wurde verändert), 
# u (= unentschlossen)
# 
# „Überarbeitungstyp":
#   a, ae, ar, aref, arep, arv, e, er, eref, erep, k, r, ref, rep, rref, v
# a = Austausch
# e = Erweiterung 
# r = Reduktion
# ref = Reformierung
# rep = Reparatur
# v = Verschiebung
# k = keine Überarbeitung (dieser Code wurde gewählt, damit keine Zeile leer bleibt)
# # 
# "Gemäß Hilfsmittel":
# j (= ja, d.h. Hilfsmittelbezug)
# n (= nein, d.h. kein Hilfsmittelbezug)
# k (= keine Angabe; zu vergeben, wenn Stolperstein gar nicht geändert wurde)

pdf("SU_plots2.pdf", onefile = T, paper = "a4r") # Es sind auch alternativ PNG-Aufrufe im Text

# Veränderung -------------------------------------------------------------

## Stolperstein verändert?!? Mittelwerte über Bedingungen
par(mar = c(5,4,4,2)+.1)
layout(matrix(1))
bargraph.CI(Bedingung, veraendert == "j", data = results, legend = F,
            bty = "n", xlab = "Revision aid condition", ylab = "Probability of modification",
            main = "", border = "#00000000",
            col = "tomato") -> bp
mtext(paste("All problems\nn =", nrow(results)), side = 3, cex = 0.7)
text(bp$xvals[,1], y = 0.1, labels = paste0("n =", table(results$Bedingung)))

tapply(results$veraendert == "j", list(results$Bedingung, results$Text), FUN = mean)
tapply(results$veraendert == "j", list(results$Bedingung, results$Text), FUN = se)

tapply(results$veraendert == "j", list(results$Bedingung), FUN = mean)
tapply(results$veraendert == "j", list(results$Bedingung), FUN = se)

tapply(results$veraendert == "j", list(results$Text), FUN = mean)
tapply(results$veraendert == "j", list(results$Text), FUN = se)

mean(results$veraendert == "j")
se(results$veraendert == "j")

## Veränderung nach Bedingung und Text
png("~/Dropbox/IDS-drop/R-Scripts/Schreibumgebung/PlotsArtikel/Fig1-changes-bw.png",
    res = 400, width = 2000, height = 2000)
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(Bedingung, veraendert == "j", Text, data = results, legend = F,
            bty = "n", xlab = "Revision aid condition", ylab = "Probability of change",
            col = c("grey20", "grey70"), border = "#00000000", names.arg = c("Only text", "Highlighted", "Full"),
            main = "") -> bp
mtext(paste("All problems\nN =", nrow(results)), side = 3, cex = 0.7)
text(bp$xvals, y = 0, pos = 3, labels = paste0("n=", table(results$Text, results$Bedingung)), col = "white", cex = 2/3)
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = c("grey20", "grey70"), legend = c("Youth", "Phraseol."),
       border = "#00000000", horiz = T)
dev.off()

## Veränderungswahrscheinlichkeit nach Bedingung und Stolpersteintyp
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(Fehlertyp1, veraendert == "j", Bedingung, data = results, legend = F,
            bty = "n", xlab = "Fehlertyp", ylab = "Wahrscheinlichkeit einer Veränderung",
            col = brewer.pal(3, "Set1"), border = "#00000000",
            main = "Veränderung nach Bedingung und Fehlertyp", cex.names = 0.8) -> bp
text(bp$xvals, y = 0.1, labels = table(results$Bedingung, results$Fehlertyp1), cex = .7, srt = 90)
par(mar = rep(0, 4))
mtext(paste("Alle Stolpersteine\nn =", nrow(results)), side = 3, cex = 0.7)
plot.new()
legend(x = "top", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       border = "#00000000", horiz = T)

## Veränderungswahrscheinlichkeit nach Bedingung und Hilfsmitteltyp
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(HM_Typ, veraendert == "j", Bedingung, data = results, legend = F,
            bty = "n", xlab = "Hilfsmitteltyp", ylab = "Wahrscheinlichkeit einer Veränderung",
            col = brewer.pal(3, "Set1"), border = "#00000000",
            main = "Veränderung nach Bedingung und Hilfsmitteltyp", cex.names = 0.8) -> bp
text(bp$xvals, y = 0.05, labels = table(results$Bedingung, results$HM_Typ), cex = .7, srt = 90)
par(mar = rep(0, 4))
mtext(paste("Alle Stolpersteine\nn =", nrow(results)), side = 3, cex = 0.7)
plot.new()
legend(x = "top", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       border = "#00000000", horiz = T)

# Verbesserung ------------------------------------------------------------

# Mittelwerte über Bedingung
par(mar = c(5,4,4,2)+.1)
layout(matrix(1, ncol = 1))
bargraph.CI(Bedingung, verbessert == "b", data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Bedingung", ylab = "Wahrscheinlichkeit einer Verbesserung",
            main = "Verbesserung nach Bedingung", border = "#00000000",
            col = "tomato") -> bp
text(bp$xvals, y = 0.1, labels = table(results[results$veraendert == "j",]$Bedingung))
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)

# Bedingung und Text
png("~/Dropbox/IDS-drop/R-Scripts/Schreibumgebung/PlotsArtikel/Fig2-improvements-bw.png",
    res = 400, width = 2000, height = 2000)
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(Bedingung, verbessert == "b", Text, data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Revision aid condition", ylab = "Probability of improvement",
            col = c("grey20", "grey70"), border = "#00000000", names.arg = c("Only text", "Highlighted", "Full"),
            main = "") -> bp
mtext(paste("Only changed problems\nN =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
text(bp$xvals, y = 0, pos = 3, labels = paste0("n=", table(results[results$veraendert == "j",]$Text,
                                                    results[results$veraendert == "j",]$Bedingung)),
     cex = 2/3, col = "white")
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = c("grey20", "grey70"), legend = c("Youth", "Phraseol."),
       border = "#00000000", horiz = T)
dev.off()

results.ch <- subset(results, veraendert == "j")

tapply(results.ch$verbessert == "b", list(results.ch$Bedingung, results.ch$Text), FUN = mean)
tapply(results.ch$verbessert == "b", list(results.ch$Bedingung, results.ch$Text), FUN = se)

tapply(results.ch$verbessert == "b", list(results.ch$Bedingung), FUN = mean)
tapply(results.ch$verbessert == "b", list(results.ch$Bedingung), FUN = se)

tapply(results.ch$verbessert == "b", list(results.ch$Text), FUN = mean)
tapply(results.ch$verbessert == "b", list(results.ch$Text), FUN = se)

mean(results.ch$verbessert == "b")
se(results.ch$verbessert == "b")

## Verbesserung nach Bedingung und Stolpersteintyp
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(Fehlertyp1, verbessert == "b", Bedingung, data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Fehlertyp", ylab = "Wahrscheinlichkeit einer Verbesserung",
            col = brewer.pal(3, "Set1"), border = "#00000000",
            main = "Verbesserung nach Bedingung und Fehlertyp", cex.names = 0.8) -> bp
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
par(mar = rep(0, 4))
text(bp$xvals, y = 0.1, labels = table(results[results$veraendert == "j",]$Bedingung,
                                       results[results$veraendert == "j",]$Fehlertyp1), cex = .7, srt = 90)
plot.new()
legend(x = "top", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       border = "#00000000", horiz = T)

## Verbesserung nach Bedingung und Hilfsmitteltyp
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(HM_Typ, verbessert == "b", Bedingung, data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Hilfsmitteltyp", ylab = "Wahrscheinlichkeit einer Verbesserung",
            col = brewer.pal(3, "Set1"), border = "#00000000",
            main = "Verbesserung nach Bedingung und Hilfsmitteltyp", cex.names = 0.8) -> bp
text(bp$xvals, y = 0.1, labels = table(results[results$veraendert == "j",]$Bedingung,
                                       results[results$veraendert == "j",]$HM_Typ), cex = .7, srt = 90)
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       border = "#00000000", horiz = T)

# Hilfsmittelbezug --------------------------------------------------------

# Mittelwerte über Bedingung
par(mar = c(5,4,4,2)+.1)
layout(matrix(1, ncol = 1))
bargraph.CI(Bedingung, gemaess.Hilfsm == "j", data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Bedingung", ylab = "Wahrscheinlichkeit des Hilfsmittelbezugs",
            main = "Hilfsmittelbezug nach Bedingung", border = "#00000000",
            col = "tomato") -> bp
text(bp$xvals, y = 0.1, labels = table(results[results$veraendert == "j",]$Bedingung))
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)

# Bedingung und Text
png("~/Dropbox/IDS-drop/R-Scripts/Schreibumgebung/PlotsArtikel/Fig4-Agreement-bw.png",
    res = 400, width = 2000, height = 2000)
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(Bedingung, gemaess.Hilfsm == "j", Text, data = results, legend = F,
            subset = veraendert == "j", border = "#00000000",
            bty = "n", xlab = "Revision aid condition", ylab = "Probability of agreement with resource",
            col = c("grey20", "grey70"),
            main = "", names.arg = c("Only text", "Highlighted", "Full")) -> bp
text(bp$xvals, y = 0, pos = 3, labels = paste0("n=", table(results[results$veraendert == "j",]$Text,
                                                           results[results$veraendert == "j",]$Bedingung)), cex = 2/3, col = "white")
mtext(paste("Only changed problems\nN =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = c("grey20", "grey70"), legend = c("Youth", "Phraseol."),
       border = "#00000000", horiz = T)
dev.off()

## Hilfsmittelbezug nach Bedingung und Stolpersteintyp
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(Fehlertyp1, gemaess.Hilfsm == "j", Bedingung, data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Fehlertyp", ylab = "Wahrscheinlichkeit des Hilfsmittelbezugs",
            col = brewer.pal(3, "Set1"), border = "#00000000",
            main = "Hilfsmittelbezug nach Bedingung und Fehlertyp", cex.names = 0.8) -> bp
text(bp$xvals, y = matrix(c(0.05, 0.2, rep(0.05, 13)), ncol = 5, nrow = 3, byrow = F),
     labels = table(results[results$veraendert == "j",]$Bedingung,
                                       results[results$veraendert == "j",]$Fehlertyp1), cex = .7, srt = 90)
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       border = "#00000000", horiz = T)

results.ch <- subset(results, veraendert == "j")

tapply(results.ch$gemaess.Hilfsm == "j", list(results.ch$Bedingung, results.ch$Text), FUN = mean)
tapply(results.ch$gemaess.Hilfsm == "j", list(results.ch$Bedingung, results.ch$Text), FUN = se)

tapply(results.ch$gemaess.Hilfsm == "j", list(results.ch$Bedingung), FUN = mean)
tapply(results.ch$gemaess.Hilfsm == "j", list(results.ch$Bedingung), FUN = se)

tapply(results.ch$gemaess.Hilfsm == "j", list(results.ch$Text), FUN = mean)
tapply(results.ch$gemaess.Hilfsm == "j", list(results.ch$Text), FUN = se)

mean(results.ch$gemaess.Hilfsm == "j")
se(results.ch$gemaess.Hilfsm == "j")

## Hilfsmittelbezug nach Bedingung und Hilfsmitteltyp
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(HM_Typ, gemaess.Hilfsm == "j", Bedingung, data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Hilfsmitteltyp", ylab = "Wahrscheinlichkeit des Hilfsmittelbezugs",
            col = brewer.pal(3, "Set1"), border = "#00000000",
            main = "Hilfsmittelbezug nach Bedingung und Hilfsmitteltyp", cex.names = 0.8) -> bp
text(bp$xvals, y = 0.1, labels = table(results[results$veraendert == "j",]$Bedingung,
                                       results[results$veraendert == "j",]$HM_Typ), cex = .7, srt = 90)
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       border = "#00000000", horiz = T)

# Sinnentstellung ---------------------------------------------------------

# Mittelwerte über Bedingung
par(mar = c(5,4,4,2)+.1)
layout(matrix(1, ncol = 1))
bargraph.CI(Bedingung, verbessert == "si", data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Bedingung", ylab = "Wahrscheinlichkeit einer Sinnentstellung",
            main = "Sinnentstellung nach Bedingung", border = "#00000000",
            col = "tomato") -> bp
text(bp$xvals, y = 0.05, labels = table(results[results$veraendert == "j",]$Bedingung))
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)

# Bedingung und Text
png("~/Dropbox/IDS-drop/R-Scripts/Schreibumgebung/PlotsArtikel/Fig3-sem_distortion-bw.png",
    res = 400, width = 2000, height = 2000)
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(Bedingung, verbessert == "si", Text, data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Revision aid condition", ylab = "Probability of semantic distortion",
            col = c("grey20", "grey70"), border = "#00000000",
            main = "", names.arg = c("Only text", "Highlighted", "Full")) -> bp
text(bp$xvals, y = 0, labels = paste0("n=", table(results[results$veraendert == "j",]$Text,
                                                  results[results$veraendert == "j",]$Bedingung)),
     col = "white", cex = 2/3, pos = 3)
mtext(paste("Only changed problems\nN =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = c("grey20", "grey70"), legend = c("Youth", "Phraseol."),
       border = "#00000000", horiz = T)
dev.off()

results.ch <- subset(results, veraendert == "j")

tapply(results.ch$verbessert == "si", list(results.ch$Bedingung, results.ch$Text), FUN = mean)
tapply(results.ch$verbessert == "si", list(results.ch$Bedingung, results.ch$Text), FUN = se)

tapply(results.ch$verbessert == "si", list(results.ch$Bedingung), FUN = mean)
tapply(results.ch$verbessert == "si", list(results.ch$Bedingung), FUN = se)

tapply(results.ch$verbessert == "si", list(results.ch$Text), FUN = mean)
tapply(results.ch$verbessert == "si", list(results.ch$Text), FUN = se)

mean(results.ch$verbessert == "si")
se(results.ch$verbessert == "si")

## Sinnentstellung nach Bedingung und Stolpersteintyp
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(Fehlertyp1, verbessert == "si", Bedingung, data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Fehlertyp", ylab = "Wahrscheinlichkeit einer Sinnentstellung",
            col = brewer.pal(3, "Set1"), border = "#00000000",
            main = "Sinnentstellung nach Bedingung und Fehlertyp", cex.names = 0.8) -> bp
text(bp$xvals, y = matrix(c(rep(0.05, 9), rep(0.15, 3), rep(0.05, 2), 0.15), ncol = 5, nrow = 3, byrow = F),
     labels = table(results[results$veraendert == "j",]$Bedingung,
                                       results[results$veraendert == "j",]$Fehlertyp1), cex = .7, srt = 90)
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       border = "#00000000", horiz = T)

## Sinnentstellung nach Bedingung und Hilfsmitteltyp
par(mar = c(5,4,4,2)+.1)
layout(matrix(1:2, ncol = 1), heights = c(.9, .1))
bargraph.CI(HM_Typ, verbessert == "si", Bedingung, data = results, legend = F,
            subset = veraendert == "j",
            bty = "n", xlab = "Hilfsmitteltyp", ylab = "Wahrscheinlichkeit einer Sinnentstellung",
            col = brewer.pal(3, "Set1"), border = "#00000000",
            main = "Sinnentstellung nach Bedingung und Hilfsmitteltyp", cex.names = 0.8) -> bp
text(bp$xvals, y = matrix(c(rep(0.05, 6), rep(0.15, 3), rep(0.05, 2), 0.15, rep(0.05, 3), rep(0.25, 3)),
                                byrow = F, ncol = 6, nrow = 3),
     labels = table(results[results$veraendert == "j",]$Bedingung,
                    results[results$veraendert == "j",]$HM_Typ), cex = .7, srt = 90)
mtext(paste("Nur veränderte Stolpersteine\nn =", nrow(subset(results, veraendert == "j"))), side = 3, cex = 0.7)
par(mar = rep(0, 4))
plot.new()
legend(x = "top", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       border = "#00000000", horiz = T)

# Veränderungstypen -------------------------------------------------------

layout(1)
par(mar = c(7, 4, 4, 2)+.1)
barplot(sort(table(results$Ueberarb.typ2), decr = T), las = 3, border = "#00000000", col = "darkgreen",
        main = "Überarbeitungstypen", ylab = "Anzahl")

## Veränderungstyp nach Text

layout(1)
par(mar = c(7, 4, 4, 2)+.1)
tab2 <- table(results$Text, results$Ueberarb.typ2)
tab2 <- tab2[,names(sort(table(results$Ueberarb.typ2), decr = T))]
par(mar = c(7, 4, 4, 2)+.1)
barplot(tab2, beside = T, col = c("darkblue", "darkred"), las = 2, border = "#00000000",
        main = "Überarbeitungstyp nach Text")
legend(x = "topright", fill = c("darkblue", "darkred"), legend = c("Jugend", "Phraseol."), inset = 0.05, title = "Text", border = "#00000000")

## Veränderungstyp nach Bedingung

tab2 <- table(results$Bedingung, results$Ueberarb.typ2)
tab2 <- tab2[,names(sort(table(results$Ueberarb.typ2), decr = T))]
layout(1)
par(mar = c(7, 4, 4, 2)+.1)
barplot(tab2, beside = T, col = brewer.pal(3, "Set1"), las = 2, border = "#00000000",
        main = "Überarbeitungstyp nach Bedingung")
legend(x = "topright", fill = brewer.pal(3, "Set1"), legend = c("nur Text", "Markierung", "Hilfsmittel"),
       inset = 0.05, title = "Bedingung", border = "#00000000")
rm(tab2)

## Veränderungstyp nach Hilfsmitteltyp, nur veränderte Stolpersteine

tab2 <- table(results[results$veraendert == "j", "HM_Typ"],
              results[results$veraendert == "j", "Ueberarb.typ2"])
tab2 <- tab2[,names(sort(table(results$Ueberarb.typ2), decr = T))]
tab2 <- tab2[,-2]
mosaicplot(t(tab2), shade = T, las = 2,
           main = "Überarbeitungstyp nach Hilfsmitteltyp")

## Veränderungstyp nach Hilfsmitteltyp, nur veränderte Stolpersteine

tab2 <- table(results[results$veraendert == "j", "Fehlertyp1"],
              results[results$veraendert == "j", "Ueberarb.typ2"])
tab2 <- tab2[,names(sort(table(results$Ueberarb.typ2), decr = T))]
tab2 <- tab2[,-2]
mosaicplot(t(tab2), shade = T, las = 2,
           main = "Überarbeitungstyp nach Fehlertyp")
rm(tab2)

# Einzelansichten Stolpersteine -----------------------------------------

### Veränderung

## Alle Bedingungen
tab3 <- prop.table(table(results$Stolperstein.ID, results$veraendert == "j"), margin = 1)
names(tab3) <- c("nicht verändert", "verändert")

reihenfolge <- c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = "."))
tab3 <- tab3[reihenfolge,c("TRUE", "FALSE")]

barplot(t(tab3), las = 2, col = c("green", "red"), cex.names = .8, border = "#00000000", space = 0.2,
        main = "Veränderungswahrscheinlichkeit (alle Bedingungen)") -> bp
abline(h = .5, lwd = 2, lty = 2)
abline(v = mean(bp[20:21]), lwd = 2)
rm(list=c("tab3", "bp", "reihenfolge"))

## Nur Text
results.nt <- subset(results, Bedingung == "nur Text")
tab3 <- prop.table(table(results.nt$Stolperstein.ID, results.nt$veraendert == "j"), margin = 1)
names(tab3) <- c("nicht verändert", "verändert")

reihenfolge <- c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = "."))
tab3 <- tab3[reihenfolge,c("TRUE", "FALSE")]

barplot(t(tab3), las = 2, col = c("green", "red"), cex.names = .8, border = "#00000000", space = 0.2,
        main = "Veränderungswahrscheinlichkeit (nur Text)") -> bp
abline(h = .5, lwd = 2, lty = 2)
abline(v = mean(bp[20:21]), lwd = 2)
rm(list=c("tab3", "bp", "reihenfolge", "results.nt"))

## Markierung
results.mark <- subset(results, Bedingung == "Markierung")
tab3 <- prop.table(table(results.mark$Stolperstein.ID, results.mark$veraendert == "j"), margin = 1)
names(tab3) <- c("nicht verändert", "verändert")

reihenfolge <- c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = "."))
tab3 <- tab3[reihenfolge,c("TRUE", "FALSE")]

barplot(t(tab3), las = 2, col = c("green", "red"), cex.names = .8, border = "#00000000", space = 0.2,
        main = "Veränderungswahrscheinlichkeit (Markierung)") -> bp
abline(h = .5, lwd = 2, lty = 2)
abline(v = mean(bp[20:21]), lwd = 2)
rm(list=c("tab3", "bp", "reihenfolge", "results.mark"))

## Hilfsmittel
results.hilf <- subset(results, Bedingung == "Hilfsmittel")
tab3 <- prop.table(table(results.hilf$Stolperstein.ID, results.hilf$veraendert == "j"), margin = 1)
names(tab3) <- c("nicht verändert", "verändert")

reihenfolge <- c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = "."))
tab3 <- tab3[reihenfolge,c("TRUE", "FALSE")]

barplot(t(tab3), las = 2, col = c("green", "red"), cex.names = .8, border = "#00000000", space = 0.2,
        main = "Veränderungswahrscheinlichkeit (Hilfsmittel)") -> bp
abline(h = .5, lwd = 2, lty = 2)
abline(v = mean(bp[20:21]), lwd = 2)
rm(list=c("tab3", "bp", "reihenfolge", "results.hilf"))

### Verbesserung

## Alle Bedingungen
results.alle <- subset(results, veraendert == "j")
tab3 <- prop.table(table(results.alle$Stolperstein.ID, results.alle$verbessert == "b"), margin = 1)
names(tab3) <- c("nicht verändert", "verändert")

reihenfolge <- c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = "."))
tab3 <- tab3[reihenfolge,c("TRUE", "FALSE")]

barplot(t(tab3), las = 2, col = c("green", "red"), cex.names = .8, border = "#00000000", space = 0.2,
        main = "Verbesserungswahrscheinlichkeit (alle Bedingungen)") -> bp
abline(h = .5, lwd = 2, lty = 2)
abline(v = mean(bp[20:21]), lwd = 2)
rm(list=c("tab3", "bp", "reihenfolge", "results.alle"))

## Nur Text
results.nt <- subset(results, Bedingung == "nur Text" & veraendert == "j")
tab3 <- prop.table(table(results.nt$Stolperstein.ID, results.nt$verbessert == "b"), margin = 1)
names(tab3) <- c("nicht verändert", "verändert")

reihenfolge <- c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = "."))
tab3 <- tab3[reihenfolge,c("TRUE", "FALSE")]

barplot(t(tab3), las = 2, col = c("green", "red"), cex.names = .8, border = "#00000000", space = 0.2,
        main = "Verbesserungswahrscheinlichkeit (nur Text)") -> bp
abline(h = .5, lwd = 2, lty = 2)
abline(v = mean(bp[20:21]), lwd = 2)
rm(list=c("tab3", "bp", "reihenfolge", "results.nt"))

## Markierung
results.mark <- subset(results, Bedingung == "Markierung" & veraendert == "j")
tab3 <- prop.table(table(results.mark$Stolperstein.ID, results.mark$verbessert == "b"), margin = 1)
names(tab3) <- c("nicht verändert", "verändert")

reihenfolge <- c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = "."))
tab3 <- tab3[reihenfolge,c("TRUE", "FALSE")]

barplot(t(tab3), las = 2, col = c("green", "red"), cex.names = .8, border = "#00000000", space = 0.2,
        main = "Verbesserungswahrscheinlichkeit (Markierung)") -> bp
abline(h = .5, lwd = 2, lty = 2)
abline(v = mean(bp[20:21]), lwd = 2)
rm(list=c("tab3", "bp", "reihenfolge", "results.mark"))

## Hilfsmittel
results.hilf <- subset(results, Bedingung == "Hilfsmittel" & veraendert == "j")
tab3 <- prop.table(table(results.hilf$Stolperstein.ID, results.hilf$verbessert == "b"), margin = 1)
names(tab3) <- c("nicht verändert", "verändert")

reihenfolge <- c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = "."))
tab3 <- tab3[reihenfolge,c("TRUE", "FALSE")]

barplot(t(tab3), las = 2, col = c("green", "red"), cex.names = .8, border = "#00000000", space = 0.2,
        main = "Verbesserungswahrscheinlichkeit (Hilfsmittel)") -> bp
abline(h = .5, lwd = 2, lty = 2)
abline(v = mean(bp[20:21]), lwd = 2)
rm(list=c("tab3", "bp", "reihenfolge", "results.hilf"))

# Veränderung: LMER -------------------------------------------------------

results$Bedingung.HM <- factor(results$Bedingung, levels = c("Markierung", "Hilfsmittel", "nur Text"))
results$Text <- factor(results$Text)
mod1 <- glmer(veraendert == "j" ~ Bedingung * Text + (1|VTn) + (1|Stolperstein.ID), data = results, family = "binomial")
summary(mod1)
plot(allEffects(mod1), multiline = T, ci.style = "bars", ylab = "Wahrscheinlichkeit Veränderung",
     xlab = "Bedingung")
rm(mod1)


# Verbesserung: LMER ------------------------------------------------------

results$Bedingung.HM <- factor(results$Bedingung, levels = c("Hilfsmittel", "Markierung", "nur Text"))
results$Text <- factor(results$Text)
mod2 <- glmer(verbessert == "b" ~ Bedingung * Text + (1|VTn) + (1|Stolperstein.ID), data = results,
              subset = veraendert == "j", family = "binomial")
summary(mod2)
mod3 <- glmer(verbessert == "b" ~ Bedingung + Text + (1|VTn) + (1|Stolperstein.ID), data = results,
              subset = veraendert == "j", family = "binomial")
anova(mod2, mod3)
summary(mod3)
mod3b <- glmer(verbessert == "b" ~ Bedingung.HM + Text + (1|VTn) + (1|Stolperstein.ID), data = results,
              subset = veraendert == "j", family = "binomial")
summary(mod3b)

rm(mod2)

# Sinnentstellung: LMER --------------------------------------------------

results$Bedingung.HM <- factor(results$Bedingung, levels = c("Hilfsmittel", "Markierung", "nur Text"))
results$Text <- factor(results$Text)
mod4 <- glmer(verbessert == "si" ~ Bedingung * Text + (1|VTn) + (1|Stolperstein.ID), data = results,
              subset = veraendert == "j", family = "binomial")
summary(mod4)
mod5 <- glmer(verbessert == "si" ~ Bedingung + Text + (1|VTn) + (1|Stolperstein.ID), data = results,
              subset = veraendert == "j", family = "binomial")
anova(mod4, mod5)
summary(mod5)
mod5b <- glmer(verbessert == "si" ~ Bedingung.HM + Text + (1|VTn) + (1|Stolperstein.ID), data = results,
              subset = veraendert == "j", family = "binomial")
summary(mod5b)

# Hilfsmittelbezug: LMER --------------------------------------------------

results$Bedingung.HM <- factor(results$Bedingung, levels = c("Hilfsmittel", "Markierung", "nur Text"))
results$Text <- factor(results$Text)
mod4 <- glmer(gemaess.Hilfsm == "j" ~ Bedingung * Text + (1|VTn) + (1|Stolperstein.ID), data = results,
              subset = veraendert == "j", family = "binomial")
summary(mod4)
mod5 <- glmer(gemaess.Hilfsm == "j" ~ Bedingung.HM + Text + (1|VTn) + (1|Stolperstein.ID), data = results,
              subset = veraendert == "j", family = "binomial")
anova(mod4, mod5)
summary(mod5)

# Differenzen Markierung-Hilfsmittel --------------------------------------

## verändert
results.mark <- results[results$Bedingung == "Markierung",]
results.hilf <- results[results$Bedingung == "Hilfsmittel",]
stst.m <- tapply(results.mark$veraendert == "j", results.mark$Stolperstein.ID, FUN = mean)
stst.m <- data.frame(Stolperstein.ID = names(stst.m), veraendert = stst.m)
stst.m <- stst.m[c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = ".")),]

stst.h <- tapply(results.hilf$veraendert == "j", results.hilf$Stolperstein.ID, FUN = mean)
stst.h <- data.frame(Stolperstein.ID = names(stst.h), veraendert = stst.h)
stst.h <- stst.h[c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = ".")),]

stst <- merge(stst.m, stst.h, by = "Stolperstein.ID", all.x = T)
rownames(stst) <- stst$Stolperstein.ID
stst <- stst[c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = ".")),]
names(stst) <- c("Stolperstein.ID", "veraendert.mark", "veraendert.hilf")
rm(list=c("results.hilf", "results.mark", "stst.h", "stst.m"))

stst$HM_diff <- stst$veraendert.hilf - stst$veraendert.mark
par(mar=c(5,5,4,2)+.1)
barplot(stst$HM_diff, col = "tomato", border = "#00000000", las = 2, cex.names = .8,
        ylab = "Differenz zwischen Markierung\nund Hilfsmittel bzgl. Veränderungen",
        main = "Hilfsmittelvorteil Veränderungen") -> bp
abline(h = 0, col = "tomato")
abline(v = mean(bp[20:21]), lwd = 2)

## verbessert
results.mark <- results[results$Bedingung == "Markierung" & results$veraendert == "j",]
results.hilf <- results[results$Bedingung == "Hilfsmittel" & results$veraendert == "j",]
stst.m <- tapply(results.mark$verbessert == "b", results.mark$Stolperstein.ID, FUN = mean)
stst.m <- data.frame(Stolperstein.ID = names(stst.m), veraendert = stst.m)
stst.m <- stst.m[c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = ".")),]

stst.h <- tapply(results.hilf$verbessert == "b", results.hilf$Stolperstein.ID, FUN = mean)
stst.h <- data.frame(Stolperstein.ID = names(stst.h), veraendert = stst.h)
stst.h <- stst.h[c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = ".")),]

stst <- merge(stst.m, stst.h, by = "Stolperstein.ID", all.x = T)
rownames(stst) <- stst$Stolperstein.ID
stst <- stst[c(paste("Jugend", 1:20, sep = "."), paste("Phraseo", 1:15, sep = ".")),]
names(stst) <- c("Stolperstein.ID", "verbessert.mark", "verbessert.hilf")
rm(list=c("results.hilf", "results.mark", "stst.h", "stst.m"))

stst$HM_diff <- stst$verbessert.hilf - stst$verbessert.mark
par(mar=c(5,5,4,2)+.1)
barplot(stst$HM_diff, col = "tomato", border = "#00000000", las = 2, cex.names = .8,
        ylab = "Differenz zwischen Markierung\nund Hilfsmittel bzgl. Verbesserungen",
        main = "Hilfsmittelvorteil Verbesserungen") -> bp
abline(h = 0, col = "tomato")
abline(v = mean(bp[20:21]), lwd = 2)

rm(list=c("stst", "bp"))

# Versuchspersonenbasierte Auswertungen -----------------------------------

# Ziel: Datenstruktur mit einem VTn pro Zeile mit assoziierten "Scores"
vp.res1 <- aggregate(results$veraendert == "j", by = list(results$VTn), FUN = sum)
names(vp.res1) <- c("VTn", "veraendert")
vp.res2 <- aggregate(results$verbessert == "b", by = list(results$VTn), FUN = sum)
names(vp.res2) <- c("VTn", "verbessert")
vp.res3 <- aggregate(results$verbessert == "si", by = list(results$VTn), FUN = sum)
names(vp.res3) <- c("VTn", "sinnentstellt")
vp.res4 <- aggregate(results$verbessert == "s", by = list(results$VTn), FUN = sum)
names(vp.res4) <- c("VTn", "verschlechtert")

vp.res <- merge(vp.res1, vp.res2, by = "VTn")
vp.res <- merge(vp.res, vp.res3, by = "VTn")
vp.res <- merge(vp.res, vp.res4, by = "VTn")
vp.res <- merge(vp.res,
                unique(results[,c("VTn", "Bedingung", "dur.Texte")]),
                by = "VTn", all.x = T, all.y = F)
rm(list=c("vp.res1", "vp.res2", "vp.res3", "vp.res4"))

tapply(vp.res$veraendert, vp.res$Bedingung, FUN = mean)
tapply(vp.res$veraendert, vp.res$Bedingung, FUN = se)
tapply(vp.res$verbessert, vp.res$Bedingung, FUN = mean)
tapply(vp.res$verbessert, vp.res$Bedingung, FUN = se)

pairwise.t.test(vp.res$veraendert, vp.res$Bedingung)
pairwise.t.test(vp.res$verbessert, vp.res$Bedingung)

png("~/Dropbox/IDS-drop/R-Scripts/Schreibumgebung/PlotsArtikel/Fig5-changed_improved_subj-bw.png",
    res = 400, width = 2000, height = 2000)
layout(1)
par(mar = c(5,4,4,2)+.1)
bargraph.CI(Bedingung, veraendert, data = vp.res, ylim = c(0, 35), col = "grey50",
            border = "#00000000", xlab = "Revision aid condition", ylab = "Number of problems changed/improved",
            main = "", names.arg = c("Only text", "Highlighted", "Full")) -> bp
bargraph.CI(Bedingung, verbessert, data = vp.res, ylim = c(0, 35), add = T, xaxt = "n", yaxt = "n",
            col = scales::alpha("black", 2/3), border = "#00000000") 
text(labels = paste0("n=", table(vp.res$Bedingung)), x = bp$xvals[,1], col = scales::alpha("white", 0.8),
     y = 0, pos = 3, cex = 2/3)
dev.off()

## Verbesserungen +, Verschlechterungen (inkl. Sinnentstellungen) -, nicht-Veränderungen 0
vp.res$score <- vp.res$verbessert - vp.res$verschlechtert - vp.res$sinnentstellt
bargraph.CI(Bedingung, score, data = vp.res, col = brewer.pal(3, "Set1"), ylim = c(0, 35),
           border = "#00000000", xlab = "Bedingung", ylab = "verbessert - (verschlechtert + sinnentstellt)",
           main = "Score pro VTn") -> bp
text(labels = table(vp.res$Bedingung), x = bp$xvals[,1], col = scales::alpha("white", 0.8),
     y = 1.5)
tapply(vp.res$score, vp.res$Bedingung, FUN = mean)
tapply(vp.res$score, vp.res$Bedingung, FUN = se)

score.tab <- table(vp.res$score, vp.res$Bedingung)
# Visualisierung der Verteilung mit einzelnen Datenpunkten

png("~/Dropbox/IDS-drop/R-Scripts/Schreibumgebung/PlotsArtikel/Fig6-Scores_per_part.png",
    res = 400, width = 1750, height = 2000)
par(mar = c(3,4,2,2)+.1)
# Plot area
plot(c(0,18), c(-5, 30), type = "n", xaxt = "n", bty = "n", ylab = "Score", xlab = "")
abline(h = seq(-5, 30, 5), col = scales::alpha("grey", .5))
abline(v = c(6,12), col = "black")
# only Text
my.pch <- 15
points(3, -4, pch = my.pch)
points(c(2.5, 3.5), rep(-3, 2), pch = my.pch)
points(c(1.5, 2.5, 3.5, 4.5), rep(1, 4), pch = my.pch)
points(c(2, 3, 4), rep(2, 3), pch = my.pch)
points(1:5, rep(3, 5), pch = my.pch)
points(3, 4, pch = my.pch)
points(c(2.5, 3.5), rep(5, 2), pch = my.pch)
points(2:4, rep(6, 3), pch = my.pch)
points(c(2.5, 3.5), rep(7, 2), pch = my.pch)
points(3, 9, pch = my.pch)
points(3, 10, pch = my.pch)
points(3, 14, pch = my.pch)
# markups
points(9, 1, pch = my.pch)
points(c(8.5, 9.5), rep(2, 2), pch = my.pch)
points(rep(9, 7), c(3,4,6,9,12,14,15), pch = my.pch)
points(rep(8.5, 6), c(7,8,13,16,17,20), pch = my.pch)
points(rep(9.5, 6), c(7,8,13,16,17,20), pch = my.pch)
points(c(8,9,10), rep(10, 3), pch = my.pch)
# lex.res.
points(rep(15, 8), c(0, 9, 12, 13, 19, 24, 25, 29), pch = my.pch)
points(rep(14.5, 3), c(16, 17, 20), pch = my.pch)
points(rep(15.5, 3), c(16,17,20), pch = my.pch)
points(c(13.5, 14.5, 15.5, 16.5), rep(18,4), pch = my.pch)
points(c(13.5, 14.5, 15.5, 16.5), rep(22,4), pch = my.pch)
points(13:17, rep(21,5), pch = my.pch)
axis(side = 1, labels = c("Only text", "Highlighted", "Full"), at = c(3, 9, 15), tick = F)
dev.off()

## Score in Zeit
vp.res$leistung <- vp.res$score / (vp.res$dur.Texte / 60)
png("~/Dropbox/IDS-drop/R-Scripts/Schreibumgebung/PlotsArtikel/Fig7-Efficiency-bw.png",
    res = 400, width = 2000, height = 2000)
bargraph.CI(Bedingung, leistung, data = vp.res, col = "grey50",
            border = "#00000000", xlab = "Revision aid condition", ylab = "Score / minute (efficiency)",
            names.arg = c("Only text", "Highlighted", "Full"),
            main = "") -> bp
text(labels = paste0("n=", table(vp.res$Bedingung)), x = bp$xvals[,1], col = scales::alpha("white", 0.8),
     y = 0, pos = 3, cex = 2/3)
dev.off()

tapply(vp.res$leistung, vp.res$Bedingung, FUN = mean)
tapply(vp.res$leistung, vp.res$Bedingung, FUN = se)

pairwise.t.test(vp.res$leistung, vp.res$Bedingung)

# Alex' Idee --------------------------------------------------------------

vp.res$verb.over.veraendert <- vp.res$verbessert / vp.res$veraendert
vp.res$plot.col <- ifelse(vp.res$Bedingung == "nur Text", "blue",
                          ifelse(vp.res$Bedingung == "Markierung", "red",
                                 ifelse(vp.res$Bedingung == "Hilfsmittel", "green", "black")))
png("C:/Users/Wolfer/Dropbox/IDS-drop/R-Scripts/Schreibumgebung/PlotsArtikel/Alex.png",
    res = 400, width = 2000, height = 2000)
plot(vp.res$veraendert, vp.res$verb.over.veraendert, pch = 19, bty = "n", col = vp.res$plot.col,
     xlab = "Verändert", ylab = "Verbesserungsrate", ylim = c(0, 1))
abline(h = 0.5, col = scales::alpha("grey", .5))
abline(v = 35/2, col = scales::alpha("grey", .5))
legend(x = "bottomright", inset = .05, legend = c("nur Text", "Markierung", "Hilfsmittel"),
       cex = .8, pch = 19, col = c("blue", "red", "green"))
dev.off()
# Ausgabe -----------------------------------------------------------------

write.table(results, file="results_excel.csv", col.names = T, row.names = F, sep = "\t")

# Einzelfälle -------------------------------------------------------------

nrow(results[results$HM_Typ == "Wortnetz" & results$Bedingung == "nur Text",])

# Zshge zwischen Stolpersteinen (inkl.PCA) --------------------------------

vtn.results <- read.csv("../../Schreibumgebung/Annotationen/Abgeschlossen4/Annotationen_komplett_JB_02.06.csv",
                        header = T, sep = ";", fileEnc = "latin1")
vars <- grep("verändert", names(vtn.results), value = T)
j.tab <- NULL
for (var in vars) {
  j.vec <- c()
  for (var2 in vars) {
    j.vec <- c(j.vec, table(vtn.results[,var], vtn.results[,var2])["j","j"])
  }
  j.tab <- cbind(j.tab, j.vec)
}
colnames(j.tab) <- vars
rownames(j.tab) <- vars
rm(list=c("j.vec", "var", "var2", "vars"))
heatmap(j.tab, symm = T)

vars <- grep("verbessert", names(vtn.results), value = T)
j.tab <- NULL
for (var in vars) {
  j.vec <- c()
  for (var2 in vars) {
    j.vec <- c(j.vec, table(vtn.results[,var], vtn.results[,var2])["b","b"])
  }
  j.tab <- cbind(j.tab, j.vec)
}
# andere Labels
labels <- sapply(vars, USE.NAMES = F, function (x) {
  splitted <- strsplit(x, "_", fixed = T)[[1]]
  text <- splitted[1]
  text2 <- substr(text, 1, 1)
  stst <- splitted[4]
  stst.id <- paste(text, stst, sep = ".")
  f.typ <- results[results$Stolperstein.ID == stst.id, "Fehlertyp1"][1]
  paste(f.typ, paste(text2, stst, sep = "."), sep = ".")
})

colnames(j.tab) <- labels
rownames(j.tab) <- labels
rm(list=c("j.vec", "var", "var2", "vars"))
heatmap(j.tab, symm = T)

library(psych)
poly.test.df <- vtn.results[,vars]
poly.test.df <- apply(poly.test.df, 2, FUN = function (x) {
  ifelse(x == "b", 1, 0)
  })
poly.test.df <- as.data.frame(poly.test.df)
cor.mat <- polychoric(poly.test.df)
PCA <- principal(cor.mat$rho, nfactors = 5, rotate="varimax",scores = T)
PCA
plot(PCA$loadings[,1], PCA$loadings[,2], bty = "n",
     xlab = "PC1 (20%)", ylab = "PC3 (16%)", type = "n", xlim = c(-0.2, 0.8))
plot.col <- ifelse(grepl(".J.", labels, fixed = T), "blue", "red")
text(PCA$loadings[,1], PCA$loadings[,2], labels = labels, cex = .7, col = plot.col)

# Clusterdiagramm
fit <- hclust(as.dist(cor.mat$rho), method = "ward.D")
plot(fit, labels = labels)

# MDS
mds <- cmdscale(as.dist(cor.mat$rho), eig = T, k = 2)
plot(mds$points[,1], mds$points[,2], type = "n")
text(mds$points[,1], mds$points[,2], labels = labels, cex = .7)

# kombinierte Plots Stolpersteine -----------------------------------------

bargraph.CI(Bedingung, veraendert == "j", data = results, col = "tomato",
            border = "#00000000", xlab = "Bedingung", ylab = "Anzahl Stolpersteine",
            main = "Stolpersteine verändert / verbessert") -> bp
bargraph.CI(Bedingung, verbessert == "b", data = results, ylim = c(0, 35), add = T, xaxt = "n", yaxt = "n",
            col = scales::alpha("black", 0.5), border = "#00000000") 
text(labels = table(vp.res$Bedingung), x = bp$xvals[,1], col = scales::alpha("white", 0.8),
     y = 3)

# Hilfsmittelkonformität vs. Verbesserung ---------------------------------

mosaicplot(with(results, table(verbessert, Bedingung, gemaess.Hilfsm)), shade = T)
with(subset(results, Bedingung == "Hilfsmittel"), table(verbessert, gemaess.Hilfsm))

cases <- subset(results, Bedingung == "Hilfsmittel" & verbessert != "b" & gemaess.Hilfsm == "j")[,c("Stolperstein.ID", "VTn",
                                                                                                    "gemaess.Hilfsm", "verbessert",
                                                                                                    "HM_Typ")]
cas.tab <- table(cases$HM_Typ)
cas.tab["Wortnetz"] <- 0
all.tab <- table(results$HM_Typ)
cas.tab <- cas.tab[names(all.tab)]
residuals(chisq.test(cas.tab, p = all.tab, rescale.p = T))

# Tassja: VP-IDs für Süddt.Dialekte ---------------------------------------

dial.res <- results[results$Dialektregion == 1,]
unique(dial.res$VTn)
st.j13 <- subset(dial.res, Stolperstein.ID == "Jugend.13", c("VTn", "Stolperstein.ID", "Bedingung",
                                                             "veraendert", "verbessert", "Ueberarb.typ", "gemaess.Hilfsm"))
write.table(st.j13, file = "Dialekt.Stst.Jug13.csv", sep = "\t", col.names = T, row.names = F)

# StSt, Fehlertypen, HM-Typen ---------------------------------------------

st.info <- unique(results[,c("Stolperstein.ID", "Fehlertyp1", "Fehlertyp2", "Fehlertyp3", "HM_Typ")])

# Informationen zu Versuchspersonen ---------------------------------------

v.info <- unique(results[,c("VTn", "Bedingung", "Mutterspr_Dt", "Fachsem", "Hochschulsem", "Sprachen",
                            "Dialektregion", "einspWB_Hfgkt", "zweispWB_Hfgkt", "allg_WB", "synonym_WB",
                            "Rechtschreib_WB", "fremd_WB", "andere1", "andere2", "keine_ang")])
table(v.info$Hochschulsem)
prop.table(table(v.info$Fachsem))
table(v.info$einspWB_Hfgkt, v.info$Bedingung)
prop.table(table(v.info$einspWB_Hfgkt, v.info$Bedingung))

tapply(results$verbessert == "j", results$einspWB_Hfgkt, FUN = mean)

